@@ -12,7 +12,9 @@
 #![feature(allocator_api)]
 #![feature(asm)]
 #![feature(const_fn_fn_ptr_basics)]
+#![feature(const_fn_trait_bound)]
 #![feature(const_fn_transmute)]
+#![feature(const_mut_refs)]
 #![feature(const_panic)]
 #![feature(const_ptr_is_null)]
 #![feature(const_ptr_offset_from)]
@@ -141,6 +143,10 @@ use std::time::SystemTime;
 pub mod big_endian;
 
 
+/// SIMD-accelerated for byte swapping large areas of memory.
+pub mod byte_swap;
+
+
 /// A set of types to support the use of bit sets in Linux APIs and files.
 #[macro_use]
 pub mod bit_set;
